@@ -1,4 +1,4 @@
-/* $Id: cxp-handler.c,v 1.13 2005/04/21 16:16:47 yasumichi Exp $ */
+/* $Id: cxp-handler.c,v 1.15 2005/08/10 16:05:22 yasumichi Exp $ */
 /**
  * \if japanese
  * @file
@@ -6,7 +6,7 @@
  *
  * @author 
  * @date Tue Mar 29 2005
- * $Revision: 1.13 $
+ * $Revision: 1.15 $
  * \endif
  * \if english
  * @file
@@ -14,7 +14,7 @@
  *
  * @author Yasumichi Akahoshi
  * @date Tue Mar 29 2005
- * $Revision: 1.13 $
+ * $Revision: 1.15 $
  * \endif
  */
 
@@ -40,8 +40,8 @@
 
 #include <glib/gi18n-lib.h>
 #include <string.h>
+#include <gconf/gconf-client.h>
 #include "cxp-utils.h"
-#include "cxp-profile.h"
 #include "cxp-handler.h"
 #include "cxp-entry-dialog.h"
 
@@ -51,7 +51,7 @@
  */
 typedef struct
 {
-	CxpProfile *profile;
+	GConfClient *client;
 	gboolean dispose_has_run;	/**< Is dispose funciton executed */
 } CxpHandlerPrivate;
 
@@ -120,7 +120,7 @@ static void cxp_handler_init (GTypeInstance * instance, gpointer g_class)
 	bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 
-	priv->profile = cxp_profile_new ("common", "handler");
+	priv->client = gconf_client_get_default ();
 	priv->dispose_has_run = FALSE;
 }
 
@@ -152,7 +152,7 @@ static void cxp_handler_dispose (GObject * obj)
 	}
 
 	priv->dispose_has_run = TRUE;
-	g_object_unref (priv->profile);
+	g_object_unref (priv->client);
 
 	G_OBJECT_CLASS (parent_class)->dispose (obj);
 }
@@ -251,8 +251,8 @@ CxpHandler *cxp_handler_new (void)
 void cxp_handler_launch (CxpHandler * handler, const gchar * fullpath)
 {
 	CxpHandlerPrivate *priv = CXP_HANDLER_GET_PRIVATE(handler);
-	gchar *filename;
-	gchar *suffix = NULL;
+	gchar *gconf_dir;
+	gchar *mime_type;
 	gchar *cmd = NULL;
 	gchar *fullcmd;
 	gchar *message;
@@ -261,48 +261,30 @@ void cxp_handler_launch (CxpHandler * handler, const gchar * fullpath)
 
 	g_return_if_fail (fullpath != NULL);
 
-	filename = cxp_path_get_basename_of_utf8 (fullpath);
-	if ((suffix = g_strrstr (filename, ".")) != NULL)
-	{
-		cmd = cxp_profile_get_string (priv->profile, suffix);
-		if (cmd == NULL)
-		{
-			message =
-				g_strdup_printf (_
-						 ("Please input the command that opens the file whose extension is %s"),
-						 suffix);
-			dialog = cxp_entry_dialog_new (_("Undefined extension"),
-						       message, "");
-			if (gtk_dialog_run (GTK_DIALOG (dialog)) ==
-			    GTK_RESPONSE_OK)
-			{
-				cmd = cxp_entry_dialog_get_entry_text
-					(CXP_ENTRY_DIALOG (dialog));
-				if ((cmd != NULL) && (strlen (cmd) > 0))
-				{
-					cxp_profile_set_string (priv-> profile, suffix, cmd);
-				}
-			}
-			gtk_widget_destroy (dialog);
-			g_free (message);
-		}
-	}
-	else
+	mime_type = cxp_get_mime_type_for_file (fullpath);
+	gconf_dir = g_strdup_printf ("/apps/cxp/mime-types/%s/open", mime_type);
+	cmd = gconf_client_get_string (priv->client, gconf_dir, NULL);
+	if (cmd == NULL)
 	{
 		message =
-			g_strdup_printf (_
-					 ("Please input the command that opens file  %s"),
-					 filename);
-		dialog = cxp_entry_dialog_new (_("File without extension"),
-					       message, "");
-		if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK)
+			g_strdup_printf (_("Please input the command that opens the file whose type is %s"),
+					mime_type);
+		dialog = cxp_entry_dialog_new (_("Undefined extension"),
+				message, "");
+		if (gtk_dialog_run (GTK_DIALOG (dialog)) ==
+				GTK_RESPONSE_OK)
 		{
-			cmd = cxp_entry_dialog_get_entry_text (CXP_ENTRY_DIALOG
-							       (dialog));
+			cmd = cxp_entry_dialog_get_entry_text
+				(CXP_ENTRY_DIALOG (dialog));
+			if ((cmd != NULL) && (strlen (cmd) > 0))
+			{
+				gconf_client_set_string (priv->client, gconf_dir, cmd, NULL);
+			}
 		}
 		gtk_widget_destroy (dialog);
 		g_free (message);
 	}
+	g_free (mime_type);
 
 	if ((cmd != NULL) && (strlen (cmd) > 0))
 	{
@@ -312,5 +294,4 @@ void cxp_handler_launch (CxpHandler * handler, const gchar * fullpath)
 		g_free (fullcmd);
 	}
 
-	g_free (filename);
 }
